@@ -95,7 +95,7 @@ class ImportCellParser:
         :return: list of stringified integers parsed from the cell
         """
         # Trim and split by semicolons
-        _value_raw_list = cellobject.value.strip().split(";")
+        _value_raw_list = str(cellobject.value).strip().split(";")
         # Trim each item and filter out empty ones, fill filtered list
         _value_numbers_set = set()
         for _item in _value_raw_list:
@@ -170,7 +170,7 @@ class ImportCellParser:
         if cellobject.value is None:
             return None
         if not isinstance(cellobject.value, str):
-            raise ImportCellParserException((f"IQF004TASKOWNERS: Cell contents type is {type(cellobject)}, "
+            raise ImportCellParserException((f"IQF004TASKOWNERS: Cell contents type is {type(_value)}, "
                                              f"string type required"))
         return self._parsenames(cellobject, ";")
 
@@ -187,7 +187,7 @@ class ImportCellParser:
             return None
         _value = cellobject.value
         if not isinstance(_value, str):
-            raise ImportCellParserException((f"IQF005TASKTIME: Cell contents type is {type(cellobject)}, "
+            raise ImportCellParserException((f"IQF005TASKTIME: Cell contents type is {type(_value)}, "
                                              f"string type required"))
         _value_split = _value.strip().split("-")
         if len(_value_split) != 2:
@@ -323,8 +323,8 @@ class ImportCellParser:
             raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
         if cellobject.value is None:
             return None
-        if not isinstance(cellobject.value, str):
-            raise ImportCellParserException((f"IQF011FREQDAYS: Cell contents type is {type(cellobject)}, "
+        if not isinstance(cellobject.value, (str, int)):
+            raise ImportCellParserException((f"IQF011FREQDAYS: Cell contents type is {type(cellobject.value)}, "
                                              f"string type required"))
         return self._parseintseq(cellobject, [1, 2, 3, 4, 5, 6, 7])
 
@@ -485,8 +485,8 @@ class ImportCellParser:
             raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
         if cellobject.value is None:
             return None
-        if not isinstance(cellobject.value, str):
-            raise ImportCellParserException((f"IQF021FREQMONTHS: Cell contents type is {type(cellobject)}, "
+        if not isinstance(cellobject.value, (str, int)):
+            raise ImportCellParserException((f"IQF021FREQMONTHS: Cell contents type is {type(cellobject.value)}, "
                                              f"string type required"))
         return self._parseintseq(cellobject, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12])
 
